Django-Front
*********************


.. image:: https://github.com/mbi/django-front/actions/workflows/test.yml/badge.svg
  :target: https://github.com/mbi/django-front/actions/workflows/test.yml
  
.. image:: https://img.shields.io/pypi/v/django-front
  :target: https://pypi.org/project/django-front/

.. image:: https://img.shields.io/pypi/l/django-front
  :target: https://github.com/mbi/django-front/blob/master/LICENSE



Django-front is a front-end editing application: placeholders can be defined in Django templates, which can then be edited on the front-end.

Currently supported editors:

* `Ace <https://ace.c9.io/>`_
* `CKEditor <http://ckeditor.com/>`_
* `EpicEditor <http://epiceditor.com/>`_
* `Froala <https://froala.com/wysiwyg-editor>`_
* `Medium Editor <https://yabwe.github.io/medium-editor/>`_
* `Redactor <http://imperavi.com/redactor/>`_
* `WYMeditor <http://www.wymeditor.org/>`_

Please see the `online documentation <http://django-front.readthedocs.org/>`_ to install and get started.

.. image:: https://travis-ci.org/mbi/django-front.png?branch=master
  :target: http://travis-ci.org/mbi/django-front


----

.. image:: http://django-front.readthedocs.org/en/latest/_images/front-edit-usage.gif




